# QICK QuACK

QuACK (**Qu**antum **A**nalog **C**ontrol **K**it) is a project written by students at Harvey Mudd College for HRL Laborartories, LLC as part of the HMC Engineering Clinic Program. It extends the open-source qick package to work with a custom Digital-to-Analog Converter (DAC) set-up.

See our website for more details.